# opnmf

Orthogonal projective non-negative matrix factorization


## Citing


If you use this software, consider citing:

Sotiras A, Resnick SM, Davatzikos C. Finding imaging patterns of structural covariance via Non-Negative Matrix Factorization. Neuroimage. 2015;108:1-16. doi:10.1016/j.neuroimage.2014.11.045